# This file was auto-generated by Fern from our API Definition.

import typing

from .data_source_component_one import DataSourceComponentOne

DataSourceComponent = typing.Union[typing.Dict[str, typing.Any], DataSourceComponentOne]
