# This file was auto-generated by Fern from our API Definition.

import typing

from .beautiful_soup_web_reader import BeautifulSoupWebReader
from .discord_reader import DiscordReader
from .document import Document
from .elasticsearch_reader import ElasticsearchReader
from .google_docs_reader import GoogleDocsReader
from .google_sheets_reader import GoogleSheetsReader
from .notion_page_reader import NotionPageReader
from .reader_config import ReaderConfig
from .rss_reader import RssReader
from .simple_web_page_reader import SimpleWebPageReader
from .slack_reader import SlackReader
from .text_node import TextNode
from .trafilatura_web_reader import TrafilaturaWebReader
from .twitter_tweet_reader import TwitterTweetReader
from .wikipedia_reader import WikipediaReader
from .youtube_transcript_reader import YoutubeTranscriptReader

DataSourceUpdateComponentOne = typing.Union[
    Document,
    TextNode,
    DiscordReader,
    ElasticsearchReader,
    NotionPageReader,
    SlackReader,
    TwitterTweetReader,
    SimpleWebPageReader,
    TrafilaturaWebReader,
    BeautifulSoupWebReader,
    RssReader,
    WikipediaReader,
    YoutubeTranscriptReader,
    GoogleDocsReader,
    GoogleSheetsReader,
    ReaderConfig,
]
