# This file was auto-generated by Fern from our API Definition.

import typing

from .chroma_vector_store import ChromaVectorStore
from .pg_vector_store import PgVectorStore
from .pinecone_vector_store import PineconeVectorStore
from .qdrant_vector_store import QdrantVectorStore
from .weaviate_vector_store import WeaviateVectorStore

DataSinkComponentOne = typing.Union[
    ChromaVectorStore,
    PineconeVectorStore,
    PgVectorStore,
    QdrantVectorStore,
    WeaviateVectorStore,
]
