# This file was auto-generated by Fern from our API Definition.

import typing

from .related_node_info import RelatedNodeInfo

TextNodeRelationshipsValue = typing.Union[RelatedNodeInfo, typing.List[RelatedNodeInfo]]
