# This file was auto-generated by Fern from our API Definition.

import typing

from .data_sink_update_component_one import DataSinkUpdateComponentOne

DataSinkUpdateComponent = typing.Union[
    typing.Dict[str, typing.Any], DataSinkUpdateComponentOne
]
