# This file was auto-generated by Fern from our API Definition.

import typing

from .data_sink_component_one import DataSinkComponentOne

DataSinkComponent = typing.Union[typing.Dict[str, typing.Any], DataSinkComponentOne]
