# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class SupportedEvalLlmModelNames(str, enum.Enum):
    """
    An enumeration.
    """

    GPT_3_5_TURBO = "GPT_3_5_TURBO"
    GPT_4 = "GPT_4"

    def visit(
        self,
        gpt_3_5_turbo: typing.Callable[[], T_Result],
        gpt_4: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is SupportedEvalLlmModelNames.GPT_3_5_TURBO:
            return gpt_3_5_turbo()
        if self is SupportedEvalLlmModelNames.GPT_4:
            return gpt_4()
